# Viziphant

[![Documentation Status](https://readthedocs.org/projects/viziphant/badge/?version=latest)](https://viziphant.readthedocs.io/en/latest/?badge=latest)
[![![PyPi]](https://img.shields.io/pypi/v/viziphant)](https://pypi.org/project/viziphant/)
[![Viziphant-tests](https://github.com/INM-6/viziphant/actions/workflows/CI_actions.yml/badge.svg)](https://github.com/INM-6/viziphant/actions/workflows/CI_actions.yml)

A Python module for easy visualization of [Neo](https://github.com/NeuralEnsemble/python-neo) objects and
[Elephant](https://github.com/NeuralEnsemble/elephant) results.

Viziphant provides a high-level API to easily generate plots and interactive visualizations of neuroscientific data and
analysis results. This API uses and extends the same structure as in Elephant to ensure intuitive usage for scientists
that are used to Elephant. 


#### Documentation
https://viziphant.readthedocs.io/en/latest/

#### Getting in touch
* Mailing list: https://groups.google.com/group/neuralensemble


#### Installation
For instructions on installing Viziphant, please see https://viziphant.readthedocs.io/en/latest/install.html

#### Copyright
:copyright: 2017-2022 by the [Viziphant team](doc/authors.rst).

#### License
BSD 3-Clause License, see [LICENSE.txt](LICENSE.txt) for details.

#### Acknowledgments
See [acknowledgments](doc/acknowledgments.rst).
